import Parse from 'parse';
/**
 * DalleOptions 绘画参数接口
 * @public
 */
export interface DalleOptions {
    prompt: string;
    quality?: null | "hd";
    n?: 1;
    model?: "dall-e-3" | "dall-e-2";
    size?: "1024x1024" | "1792x1024" | "1024x1792";
    style?: "vivid" | "natural";
}
/**
 * DALL-E-3 图片生成函数
 * @description
 * @see
 * https://p4.hosteagle.club/docs/api-reference?__cpo=aHR0cHM6Ly9wbGF0Zm9ybS5vcGVuYWkuY29t
 * @returns
 * {
      "id": "lpJGiFwWeA", // 图片生成任务ID
      "createdAt": "2024-11-27T12:18:14.463Z"
    }
 * @param {DalleOptions} options
 * @param  {string} options.prompt 1000 characters for dall-e-2 and 4000 characters for dall-e-3.
 * @param  {string} options.model dall-e-3 dall-e-2
 * @param  {string} options.quality dall-e-3 only hd means more details & consistency
 * @param  {string} options.response_format url | b64_json
 * @param  {string} options.size 1024x1024, 1792x1024, or 1024x1792 for dall-e-3
 * @param  {string} options.style vivid | natural dall-e-3 only
*/
export declare function drawDalle(options: DalleOptions): Promise<Parse.Object<Parse.Attributes>>;
